@@ -1,5 +1,8 @@
+#[macro_use]
+extern crate lazy_static;
+
+pub mod api;
 pub mod config;
 pub mod extension;
 pub mod lock;
 pub mod package;
-pub mod portal;
